@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 /*
-  Copyright 2017 - 2020 Martin Koller, kollix@aon.at
+  Copyright 2017 - 2023 Martin Koller, kollix@aon.at
 
   This file is part of liquidshell.
 
@@ -37,6 +37,8 @@
 #include <KConfigGroup>
 #include <KCMultiDialog>
 #include <KLocalizedString>
+#include <KPluginMetaData>
+#include <kcmutils_version.h>
 
 //--------------------------------------------------------------------------------
 
@@ -48,6 +50,30 @@ CalendarPopup::CalendarPopup(QWidget *parent)
 
   QVBoxLayout *vbox = new QVBoxLayout(this);
   vbox->setContentsMargins(QMargins());
+
+  timeLabel = new QLabel;
+  timeLabel->setObjectName("calendar_time");
+  QFont f = font();
+  f.setPointSizeF(fontInfo().pointSizeF() * 1.5);
+  timeLabel->setFont(f);
+  timeLabel->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
+
+  dateLabel = new QLabel;
+  dateLabel->setObjectName("calendar_date");
+  dateLabel->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
+  dateLabel->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
+
+  timer.setInterval(1000);
+  timer.start();
+
+  connect(&timer, &QTimer::timeout, this, &CalendarPopup::tick);
+
+  QHBoxLayout *hbox = new QHBoxLayout;
+  hbox->setSpacing(20);
+  hbox->addWidget(timeLabel);
+  hbox->addWidget(dateLabel);
+  vbox->addLayout(hbox);
+
   cal = new QCalendarWidget;
   vbox->addWidget(cal);
 
@@ -58,6 +84,35 @@ CalendarPopup::CalendarPopup(QWidget *parent)
 
 //--------------------------------------------------------------------------------
 
+void CalendarPopup::showEvent(QShowEvent *event)
+{
+  Q_UNUSED(event);
+
+  timer.start();
+  tick();
+}
+
+//--------------------------------------------------------------------------------
+
+void CalendarPopup::hideEvent(QHideEvent *event)
+{
+  Q_UNUSED(event);
+
+  timer.stop();  // avoid timer events we don't need
+}
+
+//--------------------------------------------------------------------------------
+
+void CalendarPopup::tick()
+{
+  // show time and date in localized long form
+  QDateTime dateTime = QDateTime::currentDateTime();
+  timeLabel->setText(locale().toString(dateTime.time()));
+  dateLabel->setText(locale().toString(dateTime.date()));
+}
+
+//--------------------------------------------------------------------------------
+
 void CalendarPopup::goToday()
 {
   cal->showToday();
@@ -71,6 +126,8 @@ void CalendarPopup::goToday()
 ClockWidget::ClockWidget(DesktopPanel *parent)
   : QFrame(parent), calendar(nullptr)
 {
+  timeFormat = locale().timeFormat(QLocale::ShortFormat);
+
   ensurePolished();  // make sure we already have the css applied
 
   timer = new QTimer(this);
@@ -149,17 +206,19 @@ ClockWidget::ClockWidget(DesktopPanel *parent)
             dialog->setAttribute(Qt::WA_DeleteOnClose);
             dialog->setWindowTitle(i18n("Date & Time"));
 
-            KPluginMetaData data(QStringLiteral("plasma/kcms/systemsettings_qwidgets/kcm_clock"));
+#if KCMUTILS_VERSION >= QT_VERSION_CHECK(5, 85, 0)
+            KPluginMetaData data("plasma/kcms/systemsettings_qwidgets/kcm_clock");
             if ( data.isValid() )
               dialog->addModule(data);
-            else
+#else
             {
               KCModuleInfo module("kcm_clock");
               if ( module.service() )
-                dialog->addModule("kcm_clock");
+                dialog->addModule(module);
               else
                 dialog->addModule("clock");  // in older KDE versions
             }
+#endif
             dialog->adjustSize();
             dialog->show();
           }
