@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 /*
-  Copyright 2017 - 2020 Martin Koller, kollix@aon.at
+  Copyright 2017 - 2023 Martin Koller, kollix@aon.at
 
   This file is part of liquidshell.
 
@@ -26,6 +26,7 @@
 #include <ConfigureDesktopDialog.hxx>
 #include <OnScreenVolume.hxx>
 #include <OnScreenBrightness.hxx>
+#include <KWinCompat.hxx>
 
 #include <QApplication>
 #include <QScreen>
@@ -37,12 +38,12 @@
 #include <QDBusConnection>
 #include <QDBusMessage>
 
-#include <KWindowSystem>
 #include <KConfig>
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KCMultiDialog>
 #include <KHelpMenu>
+#include <kcmutils_version.h>
 
 //--------------------------------------------------------------------------------
 
@@ -70,8 +71,8 @@ DesktopWidget::DesktopWidget()
   connect(panel, &DesktopPanel::resized, this, &DesktopWidget::placePanel);
   placePanel();
 
-  connect(KWindowSystem::self(), &KWindowSystem::currentDesktopChanged, this, &DesktopWidget::desktopChanged);
-  connect(KWindowSystem::self(), &KWindowSystem::numberOfDesktopsChanged, this, &DesktopWidget::loadSettings);
+  connect(KWinCompat::self(), &KWinCompat::currentDesktopChanged, this, &DesktopWidget::desktopChanged);
+  connect(KWinCompat::self(), &KWinCompat::numberOfDesktopsChanged, this, &DesktopWidget::loadSettings);
 
   setContextMenuPolicy(Qt::ActionsContextMenu);
   QAction *action = new QAction(QIcon::fromTheme("configure"), i18n("Configure Wallpaper..."), this);
@@ -180,7 +181,7 @@ void DesktopWidget::loadSettings()
   }
 
   KConfig config;
-  for (int i = wallpapers.count() + 1; i <= KWindowSystem::numberOfDesktops(); i++)
+  for (int i = wallpapers.count() + 1; i <= KWinCompat::numberOfDesktops(); i++)
   {
     KConfigGroup group = config.group(QString("Desktop_%1").arg(i));
 
@@ -195,7 +196,7 @@ void DesktopWidget::loadSettings()
     wallpapers.append(wallpaper);
   }
 
-  wallpapers.resize(KWindowSystem::numberOfDesktops());  // if we had more before, reduce size
+  wallpapers.resize(KWinCompat::numberOfDesktops());  // if we had more before, reduce size
   wallpapers.squeeze();
 
   desktopChanged();
@@ -250,7 +251,14 @@ void DesktopWidget::configureDisplay()
 {
   KCMultiDialog *dialog = new KCMultiDialog(this);
   dialog->setAttribute(Qt::WA_DeleteOnClose);
-  dialog->addModule("kcm_kscreen");
+
+  // different KDE versions need different ways ...
+  KPluginMetaData module("plasma/kcms/systemsettings/kcm_kscreen");
+  if ( module.isValid() )
+    dialog->addModule(module);
+  else
+    dialog->addModule("kcm_kscreen");
+
   dialog->adjustSize();
   dialog->setWindowTitle(i18n("Configure Display"));
   dialog->show();  // not modal
@@ -266,7 +274,7 @@ void DesktopWidget::placePanel()
   panel->setGeometry(r.x(), r.y() + r.height() - panelHeight, r.width(), panelHeight);
 
   // struts are to the combined screen geoms, not the single screen
-  KWindowSystem::setStrut(panel->winId(), 0, 0, 0, panelHeight + vs.height() - r.bottom());
+  KWinCompat::setStrut(panel->winId(), 0, 0, 0, panelHeight + vs.height() - r.bottom());
 }
 
 //--------------------------------------------------------------------------------
@@ -293,7 +301,7 @@ void DesktopWidget::desktopChanged()
   if ( (currentDesktop >= 0) && (currentDesktop < wallpapers.count()) )
     wallpapers[currentDesktop].pixmaps.clear();
 
-  currentDesktop = KWindowSystem::currentDesktop() - 1;  // num to index
+  currentDesktop = KWinCompat::currentDesktop() - 1;  // num to index
 
   if ( currentDesktop >= wallpapers.count() )
     return;
