@@ -27,7 +27,6 @@
 #include <QDebug>
 
 #include <KLocalizedString>
-#include <KNotification>
 #include <KIconLoader>
 #include <KConfig>
 #include <KConfigGroup>
@@ -61,9 +60,10 @@ PkUpdates::PkUpdates(QWidget *parent)
   updateTimer.start();
   connect(&updateTimer, &QTimer::timeout, this, &PkUpdates::checkForUpdatesReached);
 
-  setToolTip(i18n("Next check: %1 ")
-                 .arg(QDateTime::currentDateTime().addMSecs(updateTimer.interval())
-                     .toString(Qt::SystemLocaleShortDate)));
+  QString nextCheck = QDateTime::currentDateTime()
+                          .addMSecs(updateTimer.interval())
+                          .toString(Qt::SystemLocaleShortDate);
+  setToolTip(i18n("Next check: %1", nextCheck));
 
   //QTimer::singleShot(0, this, &PkUpdates::checkForUpdatesReached);
 }
@@ -297,8 +297,11 @@ void PkUpdates::createToolTip(bool notify)
 
     if ( notify )
     {
-      KNotification::event("updates available", i18n("Software Updates Available"), tooltip,
-                           QIcon::fromTheme(icon).pixmap(32), this, KNotification::Persistent);
+      if ( notification )
+        notification->close();  // close previous notification if it's still here
+
+      notification = KNotification::event("updates available", i18n("Software Updates Available"), tooltip,
+                                          QIcon::fromTheme(icon).pixmap(32), this);
     }
   }
 }
